braindecode.experiments.bcic\_iv\_2a package
============================================

.. automodule:: braindecode.experiments.bcic_iv_2a
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

braindecode.experiments.bcic\_iv\_2a.config module
--------------------------------------------------

.. automodule:: braindecode.experiments.bcic_iv_2a.config
   :members:
   :undoc-members:
   :show-inheritance:

braindecode.experiments.bcic\_iv\_2a.run module
-----------------------------------------------

.. automodule:: braindecode.experiments.bcic_iv_2a.run
   :members:
   :undoc-members:
   :show-inheritance:

